@@ -1,11 +1,12 @@
 from functools import wraps
 
-from django_utils.fields import BigIntStrRepr, BigIntStrReprSerializerField
+from django_utils.fields import BigIntStrRepr, BigIntStrReprSerializerField, JsonFieldSerializerField
 from django_utils.mock_request import MockRequest
 from global_requests import get_thread_user
 from guardian_queryset.serializers import ValidateForeignKeyUserMixin, AssignActiveUserDefaultPermissionMixin
 from rest_framework import serializers
 from reversable_primary_key.serializers import CreatedSerializerMixin
+from jsonfield import JSONField
 
 
 class BigIntStrReprSerializerMixin(serializers.Serializer):
@@ -16,6 +17,12 @@ class BigIntStrReprSerializerMixin(serializers.Serializer):
         mapping[BigIntStrRepr] = BigIntStrReprSerializerField
         return mapping
 
+class JsonFieldSerializerMixin(serializers.Serializer):
+    @property
+    def serializer_field_mapping(self):
+        mapping = super().serializer_field_mapping.copy()
+        mapping[JSONField] = JsonFieldSerializerField
+        return mapping
 
 class WithMockRequesterSerializerMixin(serializers.Serializer):
 
